<%! def inherit( context ): return context.get('base_template','basewithmenu.html') %> <%inherit file="${inherit(context)}"/> <%block name="head"> ${parent.head()}
<%block name="menu2">
×

### Create user

Username:

Password:

Processing

×

### Change password

Username:

Password:

Processing

×

### Change total request limit

Username:

Total limit:

Processing

×

### Change hourly request limit

Username:

Hourly limit:

Processing

×

### Delete a user

User to delete:

Processing

×

### Reset hourly request counter

Counter to reset:

Processing